==> google-cloud-sdk-548.0.0-darwin-arm.tar.gz: google-cloud-sdk/lib/googlecloudsdk/command_lib/datastream/objects/flags.py <==
# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Flags and helpers for the Datastream related commands."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals


def AddMysqlObjectIdentifier(parser):
  """Adds a --mysql-database & --mysql-table flags to the given parser."""
  mysql_object_parser = parser.add_group()
  mysql_object_parser.add_argument(
      '--mysql-database',
      help="""Mysql database for the object.""",
      required=True)
  mysql_object_parser.add_argument(
      '--mysql-table', help="""Mysql table for the object.""", required=True)


def AddOracleObjectIdentifier(parser):
  """Adds a --oracle-schema & --oracle-table flags to the given parser."""
  oracle_object_parser = parser.add_group()
  oracle_object_parser.add_argument(
      '--oracle-schema',
      help="""Oracle schema for the object.""",
      required=True)
  oracle_object_parser.add_argument(
      '--oracle-table', help="""Oracle table for the object.""", required=True)


def AddPostgresqlObjectIdentifier(parser):
  """Adds a --postgresql-schema & --postgresql-table flags to the given parser."""
  postgresql_object_parser = parser.add_group()
  postgresql_object_parser.add_argument(
      '--postgresql-schema',
      help="""PostgreSQL schema for the object.""",
      required=True)
  postgresql_object_parser.add_argument(
      '--postgresql-table',
      help="""PostgreSQL table for the object.""",
      required=True)


def AddSqlServerObjectIdentifier(parser):
  """Adds a --sqlserver-schema & --sqlserver-table flags to the given parser."""
  sqlserver_object_parser = parser.add_group()
  sqlserver_object_parser.add_argument(
      '--sqlserver-schema',
      help="""SQL Server schema for the object.""",
      required=True,
  )
  sqlserver_object_parser.add_argument(
      '--sqlserver-table',
      help="""SQL Server table for the object.""",
      required=True,
  )


def AddSalesforceObjectIdentifier(parser):
  """Adds a --salesforce-object-name flag to the given parser."""
  salesforce_object_parser = parser.add_group()
  salesforce_object_parser.add_argument(
      '--salesforce-object-name',
      help="""Salesforce object name.""",
      required=True,
  )

==> google-cloud-sdk-558.0.0-darwin-arm.tar.gz: google-cloud-sdk/lib/googlecloudsdk/command_lib/datastream/objects/flags.py <==
# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Flags and helpers for the Datastream related commands."""



def AddMysqlObjectIdentifier(parser):
  """Adds a --mysql-database & --mysql-table flags to the given parser."""
  mysql_object_parser = parser.add_group()
  mysql_object_parser.add_argument(
      '--mysql-database',
      help="""Mysql database for the object.""",
      required=True)
  mysql_object_parser.add_argument(
      '--mysql-table', help="""Mysql table for the object.""", required=True)


def AddOracleObjectIdentifier(parser):
  """Adds a --oracle-schema & --oracle-table flags to the given parser."""
  oracle_object_parser = parser.add_group()
  oracle_object_parser.add_argument(
      '--oracle-schema',
      help="""Oracle schema for the object.""",
      required=True)
  oracle_object_parser.add_argument(
      '--oracle-table', help="""Oracle table for the object.""", required=True)


def AddPostgresqlObjectIdentifier(parser):
  """Adds a --postgresql-schema & --postgresql-table flags to the given parser."""
  postgresql_object_parser = parser.add_group()
  postgresql_object_parser.add_argument(
      '--postgresql-schema',
      help="""PostgreSQL schema for the object.""",
      required=True)
  postgresql_object_parser.add_argument(
      '--postgresql-table',
      help="""PostgreSQL table for the object.""",
      required=True)


def AddSqlServerObjectIdentifier(parser):
  """Adds a --sqlserver-schema & --sqlserver-table flags to the given parser."""
  sqlserver_object_parser = parser.add_group()
  sqlserver_object_parser.add_argument(
      '--sqlserver-schema',
      help="""SQL Server schema for the object.""",
      required=True,
  )
  sqlserver_object_parser.add_argument(
      '--sqlserver-table',
      help="""SQL Server table for the object.""",
      required=True,
  )


def AddSalesforceObjectIdentifier(parser):
  """Adds a --salesforce-object-name flag to the given parser."""
  salesforce_object_parser = parser.add_group()
  salesforce_object_parser.add_argument(
      '--salesforce-object-name',
      help="""Salesforce object name.""",
      required=True,
  )


def AddSpannerObjectIdentifier(parser):
  """Adds a --spanner-schema & --spanner-table flag to the given parser."""
  spanner_object_parser = parser.add_group()
  spanner_object_parser.add_argument(
      '--spanner-schema',
      help="""Spanner schema name.""",
  )
  spanner_object_parser.add_argument(
      '--spanner-table',
      help="""Spanner table name.""",
      required=True,
  )
